@@ -61,13 +61,9 @@ class BaseConnection(object):
         """
 
         count_sql = "select COUNT(0) from ( %s ) temp_count" % sql
-        count_sql, params = self.sql_params(count_sql, params)
-        self.log.debug("执行SQL:" + count_sql)
-        self.log.debug("参数:" + str(params))
-        self.cursor.execute(count_sql, params)
+        self.execute(count_sql, params)
         data = self.cursor.fetchone()
         count_rows = data[0]
-        self.log.debug("影响行数:" + str(len(data)))
         num = count_rows // page_size
         if count_rows > page_size * num:
             num = num + 1
@@ -115,12 +111,8 @@ class BaseConnection(object):
         start = page_size * (page_start - 1)
         end = page_size * (page_end - page_start)
         page_sql = """SELECT * FROM ( %s ) temp_page LIMIT %d,%d """ % (sql, start, end)
-        self.log.debug("执行SQL:" + page_sql)
-        page_sql, params = self.sql_params(page_sql, params)
-        self.log.debug("参数:" + str(params))
-        self.cursor.execute(page_sql, params)
+        self.execute(page_sql, params)
         data = self.cursor.fetchall()
-        self.log.debug("影响行数:" + str(len(data)))
         if add_headers:
             col_names = self.cursor.description
             list(data).insert(col_names, 0)
@@ -151,9 +143,7 @@ class BaseConnection(object):
         :params sql:
         :return:
         """
-        self.log.debug("执行SQL:" + sql)
-        _sql, params = self.sql_params(sql, params)
-        self.cursor.execute(_sql, params)
+        self.execute(sql, params)
         data = self.cursor.fetchone()
         if data is None:
             return None
@@ -165,12 +155,8 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("执行SQL:" + sql)
-        self.log.debug("参数:" + str(params))
-        _sql, params = self.sql_params(sql, params)
-        self.cursor.execute(_sql, params)
+        self.execute(sql, params)
         data = self.cursor.fetchall()
-        self.log.debug("影响行数:" + str(len(data)))
         return data
 
     def select_dict_list(self, sql: str, params=None) -> list:
@@ -180,12 +166,8 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("执行SQL:" + sql)
-        self.log.debug("参数:" + str(params))
-        _sql, params = self.sql_params(sql, params)
-        self.cursor.execute(_sql, params)
+        self.execute(sql, params)
         data = self.cursor.fetchall()
-        self.log.debug("影响行数:" + str(len(data)))
         col_names = self.cursor.description
         return self._data_to_map(col_names, data)
 
